Changes
=======

0.2 (unreleased)
----------------

- Config sections are now CSS selectors.
- Skip images that are not supported by Pillow.

0.1 (2023-07-06)
----------------

- Add support for adding missing width and height attributes.
- Add support for "loading" and "decoding" attributes.
